ExtractDocumentError class
- Inheritance
-
- Object
- ExtractDocumentResult
- ExtractDocumentError
Constructors
-
ExtractDocumentError(Map<
Object?, Object?> json)
Properties
- error → ExtractError
-
final
- extractorId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- metaData → ExtractDocumentMetaData
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited