ExtractDocumentMetaData class

Constructors

ExtractDocumentMetaData(Map<Object?, Object?> json)

Properties

extractorType String
final
hashCode int
The hash code for this object.
no setterinherited
orientation int?
final
pageNo List<int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sliceNo int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited