FormXDataMapValue class

Inheritance

Constructors

FormXDataMapValue(Map<Object?, Object?> json, Map<String, Object?> _v)

Properties

confidence double?
finalinherited
extractedBy String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Map<String, Object?>
no setteroverride
valueType String?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited