FormXDataUnknownValue class

Inheritance

Constructors

FormXDataUnknownValue(Map<Object?, Object?> json)

Properties

confidence double?
finalinherited
extractedBy String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Object
finalinherited
valueType String?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited