ExtractDocument class
- Inheritance
-
- Object
- ExtractDocumentResult
- ExtractDocument
Constructors
-
ExtractDocument(Map<
Object?, Object?> json)
Properties
-
boundingBox
→ List<
double> ? -
final
-
data
→ Map<
String, FormXDataValue?> -
final
-
detailedData
→ Map<
String, List< FormXDataValue> > -
final
- extractorId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- metaData → ExtractDocumentMetaData
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
final
- typeConfidence → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited