FormXSDK class
Constructors
- FormXSDK()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
detect(
String imagePath) → Future< FormXDetectDocumentsResult?> - Detect documents by FormX API
-
extract(
String imagePath) → Future< FormXExtractionResult?> - Extract form data from documents by FormX API
-
init(
{required String extractorId, required String accessToken, String? apiHost}) → Future< void> -
Setup SDK with
extractorIdandaccessToken. ifapiHostis null, official formx api endpoint is used.