FormxBlurDetector class
A utility to detect if the image is blurry.
Constructors
- FormxBlurDetector({double threshold = 12})
Properties
Methods
-
isBlurry(
String imagePath) → Future< bool?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited